
# q-expansion of newform 117.10.a.g, downloaded from the LMFDB on 05 January 2025.

# We generate the q-expansion using the Hecke eigenvalues a_p at the primes.
# Each a_p is given as a linear combination
# of the following basis for the coefficient ring.

def make_data():

    from sage.all import prod, floor, prime_powers, gcd, QQ, primes_first_n, next_prime, RR

    def discrete_log(elts, gens, mod):
        # algorithm 2.2, page 16 of https://arxiv.org/abs/0903.2785
        def table_gens(gens, mod):
            T = [1]
            n = len(gens)
            r = [None]*n
            s = [None]*n
            for i in range(n):
                beta = gens[i]
                r[i] = 1
                N = len(T)
                while beta not in T:
                    for Tj in T[:N]:
                        T.append((beta*Tj) % mod)
                    beta = (beta*gens[i]) % mod
                    r[i] += 1
                s[i] = T.index(beta)
            return T, r, s
        T, r, s = table_gens(gens, mod)
        n = len(gens)
        N = [ prod(r[:j]) for j in range(n) ]
        Z = lambda s: [ (floor(s/N[j]) % r[j]) for j in range(n)]
        return [Z(T.index(elt % mod)) for elt in elts]
    def extend_multiplicatively(an):
        for pp in prime_powers(len(an)-1):
            for k in range(1, (len(an) - 1)//pp + 1):
                if gcd(k, pp) == 1:
                    an[pp*k] = an[pp]*an[k]
    from sage.all import PolynomialRing, NumberField, ZZ
    R = PolynomialRing(QQ, "x")
    f = R(poly_data)
    K = NumberField(f, "a")
    betas = [K([c/ZZ(den) for c in num]) for num, den in basis_data]
    convert_elt_to_field = lambda elt: sum(c*beta for c, beta in zip(elt, betas))
    # convert aps to K elements
    primes = primes_first_n(len(aps_data))
    good_primes = [p for p in primes if not p.divides(level)]
    aps = map(convert_elt_to_field, aps_data)
    if not hecke_ring_character_values:
        # trivial character
        char_values = dict(zip(good_primes, [1]*len(good_primes)))
    else:
        gens = [elt[0] for elt in hecke_ring_character_values]
        gens_values = [convert_elt_to_field(elt[1]) for elt in hecke_ring_character_values]
        char_values = dict([(
            p,prod(g**k for g, k in zip(gens_values, elt)))
            for p, elt in zip(good_primes, discrete_log(good_primes, gens, level))
            ])
    an_list_bound = next_prime(primes[-1])
    an = [0]*an_list_bound
    an[1] = 1
    
    from sage.all import PowerSeriesRing
    PS = PowerSeriesRing(K, "q")
    for p, ap in zip(primes, aps):
        if p.divides(level):
            euler_factor = [1, -ap]
        else:
            euler_factor = [1, -ap, p**(weight - 1) * char_values[p]]
        k = RR(an_list_bound).log(p).floor() + 1
        foo = (1/PS(euler_factor)).padded_list(k)
        for i in range(1, k):
            an[p**i] = foo[i]
    extend_multiplicatively(an)
    return PS(an)
level = 117
weight = 10
poly_data = [6898597888, 0, -399948096, 0, 2010020, 0, -2613, 0, 1]

# The entries in the following list give a basis for the
# coefficient ring in terms of a root of the defining polynomial above.
# Each line consists of the coefficients of the numerator, and a denominator.
basis_data  = [[[1, 0, 0, 0, 0, 0, 0, 0], 1], [[0, 1, 0, 0, 0, 0, 0, 0], 1], [[0, -4606636608, 0, -20387252, 0, 36753, 0, -13], 9832192], [[0, 5953137600, 0, -30219444, 0, 36753, 0, -13], 9832192], [[-653, 0, 1, 0, 0, 0, 0, 0], 1], [[2208301472, 0, -26532372, 0, 36753, 0, -13, 0], 1229024], [[2797233120, 0, -68324212, 0, 168385, 0, -93, 0], 1229024], [[0, 43614769984, 0, -303934644, 0, 462409, 0, -197], 9832192]]

hecke_ring_character_values = None
aps_data = [[0, 1, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0], [0, -7, 0, 1, 0, 0, 0, 0], [1220, 0, 0, 0, -1, -2, 1, 0], [0, -275, -4, -10, 0, 0, 0, -1], [-28561, 0, 0, 0, 0, 0, 0, 0], [0, -1196, 4, -124, 0, 0, 0, -8], [-110340, 0, 0, 0, -713, -20, -77, 0], [0, 1250, 68, -410, 0, 0, 0, 60], [0, -43690, 4, 148, 0, 0, 0, 130], [-1555508, 0, 0, 0, 751, -2846, -643, 0], [797342, 0, 0, 0, -1768, 12372, -1020, 0], [0, -269933, 476, -1155, 0, 0, 0, 1054], [-6633700, 0, 0, 0, 24704, -7350, -4866, 0], [0, -720899, 3456, -5688, 0, 0, 0, -1379], [0, -1259276, 936, -16738, 0, 0, 0, -3506], [0, -374621, -2060, -37886, 0, 0, 0, 2697], [-37310890, 0, 0, 0, -54906, 51692, -3806, 0], [-89175036, 0, 0, 0, -51143, 66808, -10999, 0], [0, 2133293, -20184, -17140, 0, 0, 0, 8217], [-119175618, 0, 0, 0, 60884, -11380, 23288, 0], [-158772212, 0, 0, 0, 132968, -61456, 520, 0], [0, 10720785, 22812, -76078, 0, 0, 0, 3543], [0, 8820397, -47740, -118677, 0, 0, 0, -20470], [-412387978, 0, 0, 0, 1169908, -223132, 47792, 0], [0, 23255782, 38176, -366676, 0, 0, 0, 23074], [-248537920, 0, 0, 0, 987592, 140750, 174498, 0], [0, -2469646, -15860, 146730, 0, 0, 0, -126248], [-478260582, 0, 0, 0, 727340, 715220, 40280, 0], [0, 16135250, 238932, 662706, 0, 0, 0, 28376], [-453169716, 0, 0, 0, -574314, -2212952, 293390, 0], [0, -47272478, -444796, 1561086, 0, 0, 0, 27156], [0, -3559845, 465884, -594791, 0, 0, 0, -82422], [1309718292, 0, 0, 0, -655830, 2160222, 451636, 0], [0, -66829541, -571440, 4057931, 0, 0, 0, -96264], [2317093388, 0, 0, 0, 8469, -2167978, 570191, 0], [3927837766, 0, 0, 0, 9190314, -297652, 137366, 0], [2219974964, 0, 0, 0, 5228489, -1027020, -670035, 0], [0, 120834465, 170304, -1965364, 0, 0, 0, -239459], [0, 176507194, 993152, 5487460, 0, 0, 0, -330738], [0, 451407224, 412988, 9554, 0, 0, 0, 166214], [905489634, 0, 0, 0, -25471238, -1195340, -1365570, 0], [0, 379879244, -1334292, 2108658, 0, 0, 0, 138474], [3099487162, 0, 0, 0, -810216, 3216180, 53156, 0], [0, 466290757, -1212696, 3556553, 0, 0, 0, -875324], [-234482020, 0, 0, 0, -40701594, -4972744, 1348782, 0], [-5934456104, 0, 0, 0, 13375508, -15771044, -210712, 0], [-10560215908, 0, 0, 0, -70263457, 13157478, 5649433, 0], [0, 277058975, 359572, -2559666, 0, 0, 0, 2844793], [525198186, 0, 0, 0, 70641548, 4333104, 352412, 0], [0, 643504058, 1506384, -33437090, 0, 0, 0, 864860], [0, -722357959, 392240, -24903464, 0, 0, 0, -1690359], [-13213849634, 0, 0, 0, 66818532, -5076576, -4329820, 0], [0, -766426782, -5302208, 18991304, 0, 0, 0, 2245258], [0, -926971586, -5253008, 22961890, 0, 0, 0, 1117308], [0, -698934750, 5001120, 40369448, 0, 0, 0, -1566550], [0, -503452566, -4944996, 60787112, 0, 0, 0, -644782], [-44322969820, 0, 0, 0, 10521063, 30324410, 1615773, 0], [-84135062822, 0, 0, 0, -149211456, -1038240, -4573344, 0], [0, -1333628473, 9603660, 57738573, 0, 0, 0, 847634], [-65583020864, 0, 0, 0, -20550950, 23025100, -15871890, 0], [0, -675579121, -1323800, -35807433, 0, 0, 0, 1211392], [-60706328700, 0, 0, 0, 204174631, -27123684, 17277075, 0], [0, -1194375446, -12796860, -92273298, 0, 0, 0, -4817156], [-21459876126, 0, 0, 0, 255708896, 80748084, -11824772, 0], [0, -694111155, -5528232, 62627581, 0, 0, 0, -1531976], [8172371996, 0, 0, 0, 328978869, -167426940, 19952329, 0], [-67399395418, 0, 0, 0, -387745576, 54118860, 29665404, 0], [0, -2216617120, -14424552, -63339540, 0, 0, 0, 18263508], [-17397898594, 0, 0, 0, 31624516, -40645816, -38693956, 0], [0, 1555118983, 22276564, 142478729, 0, 0, 0, -1453434], [0, -3846786207, 2936032, 573556, 0, 0, 0, 1824645], [52465238688, 0, 0, 0, -461543462, 44633766, 39662348, 0], [-58473835642, 0, 0, 0, -441274912, -25514888, 7071368, 0], [-144512749796, 0, 0, 0, -609943457, -66359076, -20230933, 0], [0, -17483097973, -1966936, -190676916, 0, 0, 0, -15614425], [0, -6868035280, -30901428, 127176686, 0, 0, 0, 27215874], [-6317596242, 0, 0, 0, -172070572, -192286208, 30984164, 0], [0, -25941908755, 35391748, 110800403, 0, 0, 0, 7525554], [89353671694, 0, 0, 0, -734204048, 81080308, 81726060, 0], [0, -4293674406, 48489796, -47276034, 0, 0, 0, -24026196], [33459417802, 0, 0, 0, 779729960, -6849704, -17457872, 0], [0, 23141548947, -74141392, 488156, 0, 0, 0, -1799425], [-1206421126, 0, 0, 0, 517703198, -127047908, 136636986, 0], [-182323180920, 0, 0, 0, 283332868, 8478642, -168015382, 0], [0, 12228621206, -134635324, 149695646, 0, 0, 0, 27929416], [0, 24199579445, 47871828, 256322787, 0, 0, 0, 47736554], [162267053854, 0, 0, 0, -114130252, 446679188, 23922560, 0], [0, -2288911547, -64918216, -293315351, 0, 0, 0, 14152724], [-538882090660, 0, 0, 0, -64421489, -591850002, 57680321, 0], [0, 22462490362, -54068840, 740690076, 0, 0, 0, -40585778], [0, -25963572369, 64162992, 690980404, 0, 0, 0, 8909811], [-920043135476, 0, 0, 0, -316494157, -562141630, -72362111, 0], [0, 53270686630, 38323968, 246770288, 0, 0, 0, 63492710], [-650640238108, 0, 0, 0, -1525514635, 525703656, 122718773, 0], [0, 27787373142, 29193440, -446928760, 0, 0, 0, -54633314], [0, 37082635901, -69068320, -181844531, 0, 0, 0, -46674520], [0, 56016640962, 14415380, -62126066, 0, 0, 0, -36919076], [-969238674964, 0, 0, 0, 2119138754, 80313982, 99624972, 0], [-536330039294, 0, 0, 0, 1430615896, 742527864, 237631856, 0], [-255912487964, 0, 0, 0, -4088602434, -437942694, -88975876, 0], [0, -65244821353, -105278280, 364107415, 0, 0, 0, 45339384], [0, -114218406800, 110871724, 942276738, 0, 0, 0, 68144590], [0, 28905166090, -40207912, 1032480826, 0, 0, 0, -175584176], [639274641696, 0, 0, 0, 7220693334, -631753780, 166650986, 0], [-967576166286, 0, 0, 0, -2735400032, -1053257192, -249973512, 0], [0, 118781711229, 155185748, 220755206, 0, 0, 0, 99938943], [0, -48767790135, 37562900, -1828123525, 0, 0, 0, 217551126], [0, 50407687190, 180474952, 79273452, 0, 0, 0, -54579494], [1827591667890, 0, 0, 0, 1417103360, -1028552636, 62605324, 0], [172848751304, 0, 0, 0, -969962354, 1509070806, -17794288, 0], [1728319413598, 0, 0, 0, -318697484, 2067761124, -511733504, 0], [0, -9111654897, 459102556, -459121999, 0, 0, 0, -237146314], [211425000084, 0, 0, 0, -6994311409, 433121404, -122835365, 0], [841569101196, 0, 0, 0, -4666089315, 136259662, -550224481, 0], [0, -143550486696, -175659908, 1978935936, 0, 0, 0, 11288368], [2713814201692, 0, 0, 0, -932873151, -2571950672, 588654489, 0], [0, 156528073300, -298970984, 561955788, 0, 0, 0, -35325816], [0, 102784060782, -295402340, 986348800, 0, 0, 0, 34011118], [0, -23864664748, -197935104, 1443755112, 0, 0, 0, -218538484], [2500610777518, 0, 0, 0, 333535876, 4014338884, -267470544, 0], [3911579319058, 0, 0, 0, -6041694582, -558427528, 288565482, 0], [0, 178771461508, -350413328, 167953914, 0, 0, 0, 109002626], [0, -68018327191, -62417708, -151159554, 0, 0, 0, -328239741], [3916686471324, 0, 0, 0, 6133512705, -3449989320, -360220175, 0], [0, -45335791604, 468041924, -1829847426, 0, 0, 0, -199399698], [5718955448138, 0, 0, 0, -3419862376, -1036411688, -663315296, 0], [0, -324497306990, 418761660, -1608850966, 0, 0, 0, 160377448], [-290217667988, 0, 0, 0, -239223262, 2736973092, -1153334770, 0], [320777752378, 0, 0, 0, 4123211972, -1984391284, -1256950888, 0], [-3143004269628, 0, 0, 0, 1651745731, -2536337052, -1196595737, 0], [0, 9591622217, -1051365512, -6211189992, 0, 0, 0, -180650295], [-2835399678488, 0, 0, 0, 9411736716, -4571048514, 504069654, 0], [-4316378613326, 0, 0, 0, -5772449646, 1882144756, 818168854, 0], [0, -53152246377, -235560948, -6214557183, 0, 0, 0, -89207202], [4397521981530, 0, 0, 0, -12566881976, 2334522852, 2172956228, 0], [0, -297434853557, 42316064, 1668348087, 0, 0, 0, 362581996], [1405785906604, 0, 0, 0, -9344897737, 6227702220, -41879341, 0], [0, -103373820200, 380347860, 3217169686, 0, 0, 0, -106720366], [0, -245283746242, 517531116, 7819033458, 0, 0, 0, 210798500], [-3566603655212, 0, 0, 0, 18670533219, 1309630888, 422998515, 0], [0, -41563408829, -405310200, 223011431, 0, 0, 0, -412359484], [-1192310753336, 0, 0, 0, -14993956356, -4755136642, -266406490, 0], [0, -108230668727, -1105982348, -3211075374, 0, 0, 0, -85017521], [-3863634842950, 0, 0, 0, 4801390086, 568385004, -2755449182, 0], [0, 58364642591, 376596264, -8502068588, 0, 0, 0, 460800403], [-577466937650, 0, 0, 0, 31220107520, 1025924452, 491821500, 0], [0, 261782291214, -1305374832, 6803091486, 0, 0, 0, -156956224], [4446533486656, 0, 0, 0, 15420463720, 4591100340, 1844133700, 0], [0, 63702104827, 1165554336, -9358643352, 0, 0, 0, 346781787], [5369099452486, 0, 0, 0, 5059160764, -10086330980, -1472045344, 0], [0, -176427866310, -1759315016, -2237573762, 0, 0, 0, -413546356], [-16188496524128, 0, 0, 0, -11349088082, 861397232, -775406098, 0], [0, 515508685984, 38682828, -6781594390, 0, 0, 0, -537549338], [6960102438520, 0, 0, 0, -10913391642, 11472941940, 1849981074, 0], [0, 171493508732, -140983012, -12529370134, 0, 0, 0, 319900258], [-16494362321076, 0, 0, 0, 21093059000, -10983389288, 3174767728, 0], [0, 331310221043, 1786542596, -13289250263, 0, 0, 0, 42141986], [8209655716354, 0, 0, 0, 29280343730, -17674121052, 2079862262, 0], [0, 35984865079, -1446695208, 6272801299, 0, 0, 0, -396484292], [0, 606674219503, -207075764, 18503307066, 0, 0, 0, -390983123], [0, 47248434386, -989318256, -6708050094, 0, 0, 0, -1127573616], [-4217708878876, 0, 0, 0, -2435201177, 8452119842, -1953075787, 0], [0, 122027959840, 1458106928, -14243509368, 0, 0, 0, 300568216], [0, -1805545563, 1081627076, -311779417, 0, 0, 0, 362865910], [0, 69330121035, 494854656, -2450043428, 0, 0, 0, -1737767145], [-34245614492288, 0, 0, 0, 13300844270, -3328631498, -2113356048, 0], [-750567336106, 0, 0, 0, 10403658856, 12011688816, 3704591544, 0], [-19570591668354, 0, 0, 0, 31404288988, -1243007104, 4001637292, 0], [0, -524458315966, 1377933352, 8597740812, 0, 0, 0, 553403390], [0, 79876918243, 711210732, 7536666918, 0, 0, 0, 1361948837], [20198023140766, 0, 0, 0, -5511439224, 12205743152, -5402613000, 0], [0, 486138892042, 856906932, -17262079378, 0, 0, 0, -378197700], [16870337472030, 0, 0, 0, -26618681692, -3769318772, 387278616, 0], [-21027892503344, 0, 0, 0, 11352829864, 3755280682, -599771530, 0], [0, -1107084746172, -2760771464, -12426407060, 0, 0, 0, -1839457304], [-10561105323228, 0, 0, 0, -60048507541, 2228520140, 3059263623, 0], [0, 1139034380143, 3249624576, 1898342435, 0, 0, 0, -226881388], [-25825273604704, 0, 0, 0, 54378320952, -15375327162, 8695249626, 0], [-15080338491922, 0, 0, 0, 14296938104, 21628833072, -6150878008, 0], [-66139066103940, 0, 0, 0, 34264784555, 1067606594, -4159383047, 0], [0, -25794867160, -1591605892, 23765755042, 0, 0, 0, 1280197094], [-16168399117150, 0, 0, 0, -41594953558, -9924122780, -858507554, 0], [0, 2215091412133, 1129921972, -12322117701, 0, 0, 0, -131210318], [0, 1108745047745, 1935911256, 16063422060, 0, 0, 0, 402257229], [0, 1404208705380, -4334929740, 10256641034, 0, 0, 0, 1533034122], [-18164161211142, 0, 0, 0, 47954321330, 28462205252, -1611696058, 0], [-38102456811900, 0, 0, 0, -56569154837, -12689469956, -1171038249, 0], [15959617989830, 0, 0, 0, 39304059552, 2361561560, 775687992, 0], [0, 924334247361, 1234558600, -7979027344, 0, 0, 0, -988525735], [-52560019196162, 0, 0, 0, 98368566082, 26253827096, -9851820606, 0], [0, 380281654173, 779719660, 29377281210, 0, 0, 0, -1472855029], [-44077265481724, 0, 0, 0, -28307720242, 28316667702, -2779621344, 0], [0, 2085667517851, -378424592, 5814682863, 0, 0, 0, 1056998708], [0, 2899339801852, -2636288260, 35893472746, 0, 0, 0, -225459374], [0, -2522064453626, 5469071304, -18114176574, 0, 0, 0, 537184884], [2989814478330, 0, 0, 0, -101105570824, 42354771764, 5443841092, 0], [61453542239378, 0, 0, 0, 98204351088, 202058392, 5043938712, 0], [0, 943389971617, -4219386916, -9108483829, 0, 0, 0, 15020974], [0, -2398825597812, -9215449308, 9070174254, 0, 0, 0, -768429074], [0, -2313596747859, 6731796096, -32086010287, 0, 0, 0, 366546468], [-87177578446344, 0, 0, 0, 43984231318, 16699235030, -3299792264, 0], [76121917126610, 0, 0, 0, 154541436948, -39254396852, -1199891336, 0], [21528832954142, 0, 0, 0, -125079734886, 36594383840, -5379621166, 0], [0, -596020783173, -7149033380, 2892894582, 0, 0, 0, -5735945603], [0, 1223127054736, -10654317608, 29825847834, 0, 0, 0, 5158259118], [3170582499716, 0, 0, 0, -75362411705, -63994967734, 8071213933, 0], [0, -4010570998842, 2779797300, 45212046942, 0, 0, 0, 2528270904], [0, -3204495518447, 210533548, -17813149209, 0, 0, 0, 704088162], [15525513658944, 0, 0, 0, -43347724162, -60101182776, -7852768698, 0], [27932345449690, 0, 0, 0, -79497899970, 12338789636, -17547594030, 0], [0, -4699664475752, 2919400600, 5070611854, 0, 0, 0, -1518934382], [-78784569633612, 0, 0, 0, -14206258828, 20649990488, -3995491188, 0], [0, 1796443787261, 13381803300, -16103302518, 0, 0, 0, -2218232789], [0, -1451483146177, -6617799816, 55075636136, 0, 0, 0, 2008868159], [-32258883405070, 0, 0, 0, 82243139532, 10326607252, 8314950040, 0], [-20684691032364, 0, 0, 0, -86254785832, -75727752556, -2491558108, 0], [0, 1457407844408, 476487544, -14934766876, 0, 0, 0, -1008681676], [0, 593476599017, 4831359896, -6417692200, 0, 0, 0, -2533243863], [0, -2395889532929, 3617723160, 60524004787, 0, 0, 0, -3717233532], [1900486506250, 0, 0, 0, 94120490280, 17676933808, 881106008, 0], [-43688883727532, 0, 0, 0, 68703561691, 26793320858, 6158024401, 0], [0, -1748547349563, -2175503828, 1797550147, 0, 0, 0, -1390279286], [17825884411892, 0, 0, 0, 128237644339, -53474378126, -3045929519, 0], [0, 170964314962, 9557027512, 91353145564, 0, 0, 0, -2759734906], [37645196061430, 0, 0, 0, 139031006224, -159542344552, 9118816024, 0], [0, 2961911537068, 4515716888, 13950993332, 0, 0, 0, -9583500088], [0, 1898706062066, 18588190840, 34511387004, 0, 0, 0, 5887623750], [33713389855140, 0, 0, 0, -53589275826, 150938675156, -4221276854, 0], [0, -1930438045793, -1308304348, 85854101614, 0, 0, 0, 3629257097], [18633964492506, 0, 0, 0, 33644412842, -40874707156, 22247188022, 0], [-43636392632260, 0, 0, 0, -126895146554, 117507841318, -16578210840, 0], [-11611628982892, 0, 0, 0, -267530821267, -34927008002, 15744255327, 0], [0, -1624445740848, -4592481172, 75913092708, 0, 0, 0, 1388248948], [-115525995653452, 0, 0, 0, 303677045362, 23858255290, -1200805648, 0], [0, 3877605511977, -10279085792, 4209633004, 0, 0, 0, -10172097499], [123975200291430, 0, 0, 0, -126664339480, -27926801436, -9658913676, 0], [0, -3458439341873, 8440066784, 1434731011, 0, 0, 0, -2858276908], [0, -5029798999100, 143008732, -14514585878, 0, 0, 0, 5809097306], [0, 1237825231956, -12804238732, 15232177310, 0, 0, 0, 2329435334], [0, 3659039110313, -8509873308, -123100127134, 0, 0, 0, 568356399], [-45007041768176, 0, 0, 0, -21792033194, 93155783100, -19503877062, 0], [-199754936198860, 0, 0, 0, 103793932948, -16035600812, -18807475040, 0], [142599830834190, 0, 0, 0, -315139974252, 17315629552, -24047504524, 0], [0, -1731210974239, 40648236516, -17764920409, 0, 0, 0, -10589648030], [0, 2279715986450, 8166248740, 45186829270, 0, 0, 0, 7290319260], [56933446305236, 0, 0, 0, 48802869047, -102078308866, -11481484647, 0], [0, 533763394919, 18582740460, -97349296374, 0, 0, 0, 3417759669], [17039048076468, 0, 0, 0, -5676598641, -177543559908, 25920875067, 0], [0, 2029854897746, -4934110356, -17769229526, 0, 0, 0, 5213192360], [134779549556194, 0, 0, 0, -99007524624, 64814855144, 49102919352, 0], [0, 3253018448411, 12333841948, 163206388261, 0, 0, 0, -4932028178], [0, -4991475679813, -13161657152, -151211573736, 0, 0, 0, -8263359029], [110658095653422, 0, 0, 0, 135131101808, -59358351172, 12377133380, 0], [0, 6659137386814, 21742139036, -20906680532, 0, 0, 0, 5891495682], [0, -4203421216211, 1609559692, 81608301814, 0, 0, 0, 3548022831], [63152959761978, 0, 0, 0, 195966466224, -26433939672, 41816168, 0], [-136181320078908, 0, 0, 0, -342171283701, 5287271684, -1623474545, 0], [0, -897248053788, 1737036004, 31673789950, 0, 0, 0, 9256828742], [215955675643010, 0, 0, 0, -17138609772, 240375673908, -9201763232, 0], [-266309965204092, 0, 0, 0, -280544129618, 116153681164, -17717602190, 0], [0, 13656783957916, -2380261616, -90088323944, 0, 0, 0, -2400839804], [266509405407794, 0, 0, 0, 39898670508, 61772283900, -4973228848, 0], [161020090383710, 0, 0, 0, -165539262728, -112136524648, 14773917696, 0], [0, 5720987622021, -21456615708, 140604396263, 0, 0, 0, -4305143914], [24480963254096, 0, 0, 0, -462977745576, 118514400888, 31618216000, 0], [0, -270084500475, -4701500288, -15853508003, 0, 0, 0, -4527103152], [0, 10443571459999, 22975422276, 129961947617, 0, 0, 0, 12398470374], [-99405284051060, 0, 0, 0, 626209083071, -71377093316, -11943032277, 0], [0, -5397202474662, -7630399192, -279242561668, 0, 0, 0, 23120875974], [-47568340030666, 0, 0, 0, -82711485390, -121615461452, -65335885290, 0], [65545879731868, 0, 0, 0, -499724231011, -15062337924, 32905612121, 0], [-20394227408538, 0, 0, 0, -164866362828, -82447301032, -16633484916, 0], [70784692234632, 0, 0, 0, -439560843672, 254769069910, -12131855462, 0], [38902351174150, 0, 0, 0, 152704110304, -63283721740, -88049796324, 0], [-67011606415332, 0, 0, 0, -301601153175, -195189317870, 48025989303, 0], [0, -8928092472217, -25169362436, -266315437438, 0, 0, 0, -4905222323], [170244317995310, 0, 0, 0, -208621857028, 80885044912, -57300250676, 0], [135204171053466, 0, 0, 0, 363026918544, 164215111296, -39909161344, 0], [0, -12143861155262, 35867335008, 295064489736, 0, 0, 0, 17534249130], [0, 11723783296396, 22069476964, -19401025178, 0, 0, 0, -11158038570], [-46821654198540, 0, 0, 0, 910266594003, 165299680698, 36366707241, 0], [0, -8309536734940, -24085985132, 86982323606, 0, 0, 0, 14022250238], [-114891262676034, 0, 0, 0, 433377931480, 70049082876, -2750734484, 0], [-42487506148724, 0, 0, 0, -232417899025, -107602517460, 24658117035, 0], [0, -14087650938640, 13580539952, -20555909800, 0, 0, 0, 25867871224], [-158355699298282, 0, 0, 0, 278093817566, 2009595588, -15568358574, 0], [0, -10895712224357, 40990509624, 206443670379, 0, 0, 0, -15342835928], [-137950129632268, 0, 0, 0, -773626710203, 257237645706, -6855154085, 0], [0, -24988021623406, 24155663376, -190980984962, 0, 0, 0, -7413811436], [0, 18442122869472, 2930003864, -231627504890, 0, 0, 0, -19508291486], [0, 34365818040, 53306413880, 179805453172, 0, 0, 0, 33469179140], [0, -8559589275775, -28582591772, 338832371283, 0, 0, 0, 3138031126], [0, -3635558497909, 27994218732, -316011647214, 0, 0, 0, 8331841873], [-34960121672346, 0, 0, 0, -389258274198, 262873678724, 113215835390, 0], [0, 2353085370184, 13748134228, -453644546978, 0, 0, 0, 11702988090], [-397200875546968, 0, 0, 0, -503815807710, 74498972558, 49407008876, 0], [0, -849037793064, -52210536868, -250496515742, 0, 0, 0, 6925406438], [0, 25899096775900, -25007008952, 296332731620, 0, 0, 0, -11827886280], [-516486788502100, 0, 0, 0, 145651466363, -305778473004, -67106608497, 0], [-628471521763318, 0, 0, 0, 492963644344, 67724223160, 3118251616, 0], [0, -29214762302587, 9896604480, -430050933351, 0, 0, 0, -7838582348], [-232511337958208, 0, 0, 0, -472766782888, -432106970670, 18539197694, 0], [0, -13755677894688, -36954616864, -70860279752, 0, 0, 0, 4867354600], [-140045044697596, 0, 0, 0, -605095513118, -85963550742, 141442038544, 0], [-45020031421762, 0, 0, 0, 1696951655688, 9303765704, 109689547376, 0], [0, -3093137892864, 5319542676, -414025964874, 0, 0, 0, -22705995574], [-85917665279358, 0, 0, 0, -280776165352, -614370711728, 95923449256, 0], [0, 942889050547, 62613924944, -83972407396, 0, 0, 0, 43869381519], [-144821715604634, 0, 0, 0, 1037961674448, 53724501200, -37028746016, 0], [0, 6475864021778, -30726854248, 525200111996, 0, 0, 0, -37313775770], [0, 20495490298157, 23085222744, 87333868101, 0, 0, 0, -36862986512], [0, -17691970413238, 88238479924, -242060950314, 0, 0, 0, -19713449700], [-334371433492616, 0, 0, 0, 50864259900, 474861410880, -110303330308, 0], [0, -4741362294663, 6401622024, 182435442420, 0, 0, 0, -5620390755], [605518758780270, 0, 0, 0, 649583973704, -279802108324, -171873834020, 0], [0, 15430657707959, -8115841324, 273868289326, 0, 0, 0, -31845553695], [0, 12265822325995, 54698775936, 555704687692, 0, 0, 0, -21731595481], [-823806094222626, 0, 0, 0, -549511154196, 76793269520, -31148838852, 0], [0, 2123817567912, -29399564788, 212906407828, 0, 0, 0, 11749327004], [13059037308884, 0, 0, 0, 515991085752, 458021540682, -203903982090, 0], [-515418946552990, 0, 0, 0, -864719109364, 77827446628, -71007993480, 0], [0, 646037965140, -127819589480, -318591204698, 0, 0, 0, 45499275686], [-109843759662932, 0, 0, 0, 1117599530673, 432582927390, -20118009597, 0], [0, 2015227402493, 37077383764, 361130489003, 0, 0, 0, 68415951370], [262642572198662, 0, 0, 0, -522075265586, -275660054204, 23350812642, 0], [1036493583971268, 0, 0, 0, -1699773122167, -207400004852, 110392175989, 0], [-930089454393788, 0, 0, 0, -765876540247, -272224738324, -55464472267, 0], [0, -42219956694040, 130824960344, -199068402812, 0, 0, 0, -22553041372], [0, 19934491357206, 62937441052, 31820949968, 0, 0, 0, 16541824294], [179870974831666, 0, 0, 0, -1865846936908, 168576737960, 152494792140, 0], [0, -36971964289686, 100311811876, 167183727188, 0, 0, 0, 28434137734], [1401406131309532, 0, 0, 0, -894633305008, 55999473892, -164043643764, 0], [0, 7719932568813, -51747992620, -21012122042, 0, 0, 0, 43506413679], [7688704179604, 0, 0, 0, 1811677114367, -359139629772, 158850491507, 0], [0, 12694461223837, -3666564156, -19509534170, 0, 0, 0, 22170707279], [-19528966295426, 0, 0, 0, 838385854324, 490092673624, -165485922948, 0], [0, 28020508595795, -44440736764, 132884744933, 0, 0, 0, 32488213270], [-587940589458058, 0, 0, 0, -1188319955208, 253301594616, 168494895216, 0], [375707713057480, 0, 0, 0, 1073103381604, -103457876678, -43640324574, 0], [64663581793446, 0, 0, 0, 3349617503420, -97781937496, 5074094436, 0], [0, -16758575081822, 22791289900, 168323467710, 0, 0, 0, 22027346076], [0, -7181819982117, 50405832888, 753374182731, 0, 0, 0, -50453424456], [437109855032568, 0, 0, 0, 569626829304, -646258243238, -145649004490, 0], [0, 22693733181817, 126301600824, 554650871465, 0, 0, 0, -22558504808], [0, 8434769656928, 64124287812, 847010944094, 0, 0, 0, -36820990334], [-551381153213206, 0, 0, 0, 281953494576, -622278427352, -173583496664, 0], [-433434584254220, 0, 0, 0, 267102093289, -16616661464, -123533413751, 0], [0, 17778097949537, -129275895848, 991864703404, 0, 0, 0, -29348495139], [0, 40462520146292, -59604338868, -968444233386, 0, 0, 0, -39900036114], [-176145043364012, 0, 0, 0, 589296219105, -991651907380, 86615838605, 0], [-174093554997530, 0, 0, 0, 1790431547444, -674465056760, 105561582844, 0], [0, -8212345961497, -43679472464, -133362808833, 0, 0, 0, 100544648704], [35069529763156, 0, 0, 0, 2360357330614, 364529280836, -64037442814, 0], [177892899195662, 0, 0, 0, -1490769614366, 468412501420, 169301697806, 0], [0, -23753711328774, -52404223308, -156509562902, 0, 0, 0, -6418846872], [0, 58577100263313, 137771547952, -535047737360, 0, 0, 0, -11746144903], [0, 68575294425475, -82183845020, -767956916658, 0, 0, 0, -42294794963], [0, -75238350117066, -78454723480, 523109646206, 0, 0, 0, 17599066072], [0, 51250420813699, -90988882120, -609421088, 0, 0, 0, 11085614299], [-899111920017506, 0, 0, 0, -684222139692, -457792797780, -9497484408, 0], [0, -13781347933240, 181113631780, 522313875572, 0, 0, 0, -89694686804], [0, 48554777136370, 155893654776, 163160807220, 0, 0, 0, 55783095246], [0, -46294980603265, 21184650932, -1127448027846, 0, 0, 0, 34148480093], [-116673472828324, 0, 0, 0, -1050798877196, 1924714632014, -76659505026, 0], [5812371238058, 0, 0, 0, -2543096990234, -646371299288, -178291341690, 0], [0, -8906908573347, 113922019840, -33520209007, 0, 0, 0, 129151309732], [-318136789650108, 0, 0, 0, 4005282818901, 267916198754, 248782219251, 0], [-518740773581462, 0, 0, 0, -653767612654, -279546352816, 265267509210, 0], [0, 19628780324626, -2849015052, -1178099675434, 0, 0, 0, 35242451916], [-953513630555716, 0, 0, 0, -2424200217536, -1285783173110, -79326013474, 0], [0, -15892294736323, 17898363776, -389969109308, 0, 0, 0, 130001687361], [0, -79049676935120, -218938660784, 334958573770, 0, 0, 0, -43518128946], [622547966539316, 0, 0, 0, 787142055820, -924251424700, -184165463640, 0], [467596499154930, 0, 0, 0, 2832730800200, 1200958895248, 15051876792, 0], [0, 27136516971441, 200505892532, -206109334738, 0, 0, 0, -38424547493], [0, -14159894340932, 230542109240, -390646484020, 0, 0, 0, -63185323568], [-845387382902390, 0, 0, 0, 3621321465052, 371021023604, 247129219176, 0], [0, -13874366956716, -233119410048, -1365098314592, 0, 0, 0, -53967314524], [-96508420097050, 0, 0, 0, 2782724472390, -408569203152, 357886771070, 0], [0, -34544353292677, -140532822552, 720780880987, 0, 0, 0, 64311285624], [0, -29734585481853, 67382189132, 1362477218965, 0, 0, 0, 11860329206], [2183867767277028, 0, 0, 0, 3066691666071, -647119054354, -229529715127, 0], [0, 51834395360525, 95979519596, -863162899869, 0, 0, 0, -66935870206], [1146351559055676, 0, 0, 0, 1010020803785, 178030564432, 176596463041, 0], [0, 30040666642443, 149892855680, 858479437456, 0, 0, 0, -126267556525], [-316182943111028, 0, 0, 0, -3904632036399, 158606616390, 340879445979, 0], [-298667389626478, 0, 0, 0, -1983957029362, -504494319132, 534541421170, 0], [172387331314964, 0, 0, 0, 1357516432967, -1419782926844, 413827209323, 0], [0, -28516944920494, -87700518584, -725117788084, 0, 0, 0, 12505083478], [1264122483628622, 0, 0, 0, -3383664387340, 700655079448, 34524808556, 0], [0, -35589524753729, -73337783112, -1047278946385, 0, 0, 0, -53553714392], [0, -22292054904811, -44408002084, -795237826658, 0, 0, 0, 209114492431], [1011398019574672, 0, 0, 0, -2780258127280, 1092214554244, -405183065668, 0], [0, -53354655778947, -220430606824, -601135752248, 0, 0, 0, -148302619203], [-1279081089541410, 0, 0, 0, 1819928576638, -434729150532, -207581549382, 0], [2816276421128532, 0, 0, 0, -4194941856639, -1376371271170, 409473782483, 0], [0, -29669400012724, 56940489212, -1001672466908, 0, 0, 0, 25364269248], [-67258079801688, 0, 0, 0, -114027642164, -14014369912, -62181501884, 0], [0, 48002995545749, -234445962112, 1538722325357, 0, 0, 0, 59993064048], [-1342058625503938, 0, 0, 0, 728976139188, 1472400282152, -342089422676, 0], [0, -73091470233160, 16285904908, 1044996494352, 0, 0, 0, 132024960352], [1118968364492604, 0, 0, 0, -945877423685, -167937357162, -341166130619, 0], [0, 57878058733445, -93949548372, 1360435588975, 0, 0, 0, -134245089602], [0, 25841303445161, -6522196408, -517335972423, 0, 0, 0, 161330260920], [1467847594551716, 0, 0, 0, 1778452472964, 222847380932, -253413988512, 0], [-948669772087174, 0, 0, 0, 323205004996, -1164343756564, -289396634872, 0], [0, 74635533396153, 93639695492, -97662631253, 0, 0, 0, 186298051654], [1044848950226716, 0, 0, 0, -4702175281649, -69414501860, 86837660443, 0], [0, 95125363633229, 146101251180, 63527450298, 0, 0, 0, 149024880683], [-808755521928158, 0, 0, 0, 135922801104, 706787634992, 394530148096, 0], [0, 57612824473236, 448403888544, 1161226825674, 0, 0, 0, 118762384066], [0, -73716069859528, -145143905720, 857325018076, 0, 0, 0, -127473119780], [793467625922076, 0, 0, 0, 4404005690044, 676711694578, -398224711502, 0], [-2013552045324458, 0, 0, 0, -2450593775392, -2274384645168, -59229971536, 0], [0, -14660716875268, 155406339968, -1988976370306, 0, 0, 0, 71789197958], [0, -10759189333715, -175447585024, 1145814010968, 0, 0, 0, 159671063709], [1552578653707780, 0, 0, 0, 1440772606756, -853484255740, 121516505792, 0], [0, -8013846301763, 281477265716, -2307214215597, 0, 0, 0, -28141807902], [0, -6717127684226, -30159844812, 194188318622, 0, 0, 0, 266077022432], [0, -64562123827322, -341762012368, -164994761768, 0, 0, 0, -259957520506], [-755412121735450, 0, 0, 0, -5119152255144, 1087449674872, 338440182896, 0], [0, 72574533434721, 220173861336, -1862741400364, 0, 0, 0, 120987731765], [0, -8651785899282, 405560609396, -52249516274, 0, 0, 0, -145543270864], [1221595696150762, 0, 0, 0, 5226181409428, 809234458640, -432866460252, 0], [0, 60766763417939, -264922653536, 164785024711, 0, 0, 0, -74721199484], [0, -104555965453898, -472417158192, 452602093656, 0, 0, 0, -167324142578], [0, 25644435098029, 368602640284, -2794328951469, 0, 0, 0, 127802473266], [1580429527847068, 0, 0, 0, 390593686289, -2507427250976, -161531926791, 0], [0, -53317424626528, 45142154420, 253167162174, 0, 0, 0, 120156649298]]
